Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(444)

Unified Diff: frog/value.dart

Issue 8618004: Fix Swarm to run again, and enable its test (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 9 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« client/tests/client/client.status ('K') | « frog/gen.dart ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: frog/value.dart
diff --git a/frog/value.dart b/frog/value.dart
index c6549b965538fa6231cf3ce830ec5ad1ca465d26..019ee38cc552868606f134ffeb83bec8598cfc73 100644
--- a/frog/value.dart
+++ b/frog/value.dart
@@ -337,9 +337,11 @@ class Value {
toType = p.extendsType;
}
// TODO(jmesserly): fix checking of function types.
// For now, don't generate a broken check.
- if (toType.getCallMethod() != null) {
+ // (For DOM types to work right, we need to lazily patch the "is$DOMWindow"
+ // check methods, by catching it on Object.prototype like VarMember does)
jimhug 2011/11/22 18:20:14 Niggling worry - does this change conflict with St
+ if (toType.getCallMethod() != null || toType.library == world.dom) {
return this;
}
« client/tests/client/client.status ('K') | « frog/gen.dart ('k') | no next file » | no next file with comments »
@@ -337,9 +337,11 @@ class Value {
toType = p.extendsType;
}
- // TODO(jmesserly): fix checking of function types.
+ // TODO(jmesserly): fix checking of function types, and DOM objects
// For now, don't generate a broken check.

Powered by Google App Engine
This is Rietveld 408576698